@@ -14,7 +14,6 @@
 
 namespace Plasma
 {
-
 class DataEngine;
 class Package;
 class Corona;
@@ -56,9 +55,7 @@ public:
      * @param containmentId a unique id used to differentiate between multiple
      *      instances of the same Applet type
      */
-    explicit Containment(QObject *parent = nullptr,
-                         const QString &serviceId = QString(),
-                         uint containmentId = 0);
+    explicit Containment(QObject *parent = nullptr, const QString &serviceId = QString(), uint containmentId = 0);
 
     /**
      * This constructor is to be used with the plugin loading systems
@@ -286,6 +283,14 @@ public Q_SLOTS:
      */
     void setFormFactor(Plasma::Types::FormFactor formFactor);
 
+    /**
+     * Set Display hints that come from the containment that suggest the applet how to look and behave.
+     *
+     * @param hints the new hints, as bitwise OR
+     * @since 5.77
+     */
+    void setContainmentDisplayHints(Plasma::Types::ContainmentDisplayHints hints);
+
     /**
      * Sets the type of this containment.
      */
