@@ -1,32 +1,18 @@
 /*
- *   Copyright 2010 by Ryan Rix <ry@n.rix.si>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2010 Ryan Rix <ry@n.rix.si>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef PLUGIN_LOADER_H
 #define PLUGIN_LOADER_H
 
+#include <KPluginInfo>
 #include <plasma/package.h>
 #include <plasma/plasma.h>
-#include <kplugininfo.h>
 
 namespace Plasma
 {
-
 class Applet;
 class Containment;
 class ContainmentActions;
@@ -35,7 +21,7 @@ class Service;
 
 class PluginLoaderPrivate;
 
-//TODO:
+// TODO:
 // * add loadWallpaper
 // * add KPluginInfo listing support for Containments (already loaded via the applet loading code)
 
@@ -65,8 +51,7 @@ public:
      * @param args to send the applet extra arguments
      * @return a pointer to the loaded applet, or 0 on load failure
      **/
-    Applet *loadApplet(const QString &name, uint appletId = 0,
-                       const QVariantList &args = QVariantList());
+    Applet *loadApplet(const QString &name, uint appletId = 0, const QVariantList &args = QVariantList());
 
     /**
      * Load a dataengine plugin.
@@ -82,23 +67,26 @@ public:
      * @param parentApp the application to filter dataengines on. Uses the
      *                  X-KDE-ParentApp entry (if any) in the plugin info.
      *                  The default value of QString() will result in a
-     *                  list containing only dataengines not specifically
-     *                  registered to an application.
+     *                  list of all dataengines.
      */
     static QStringList listAllEngines(const QString &parentApp = QString());
 
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 77)
     /**
      * Returns a list of all known dataengines.
      *
      * @param parentApp the application to filter dataengines on. Uses the
      *                  X-KDE-ParentApp entry (if any) in the plugin info.
      *                  The default value of QString() will result in a
-     *                  list containing only dataengines not specifically
-     *                  registered to an application.
+     *                  list of all dataengines.
      * @return list of dataengines
+     * @deprecated since 5.77, use listDataEngineMetaData instead.
      **/
+    PLASMA_DEPRECATED_VERSION(5, 77, "Use listDataEngineMetaData instead")
     static KPluginInfo::List listEngineInfo(const QString &parentApp = QString());
+#endif
 
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 81)
     /**
      * Returns a list of all known dataengines filtering by category.
      *
@@ -110,12 +98,14 @@ public:
      * @param parentApp the application to filter dataengines on. Uses the
      *                  X-KDE-ParentApp entry (if any) in the plugin info.
      *                  The default value of QString() will result in a
-     *                  list containing only dataengines not specifically
-     *                  registered to an application.
+     *                  list of all dataengines in specified categories.
      * @return list of dataengines
+     * @deprecated since 5.81, use listDataEngineMetaData() instead.
      * @since 4.3
      **/
+    PLASMA_DEPRECATED_VERSION(5, 81, "Use listDataEngineMetaData instead")
     static KPluginInfo::List listEngineInfoByCategory(const QString &category, const QString &parentApp = QString());
+#endif
 
     /**
      * Load a Service plugin.
@@ -126,7 +116,7 @@ public:
      *
      * @return a Service object, unlike Plasma::Service::loadService, this can return null.
      **/
-    Service *loadService(const QString &name, const QVariantList &args, QObject *parent = 0);
+    Service *loadService(const QString &name, const QVariantList &args, QObject *parent = nullptr);
 
     /**
      * Load a ContainmentActions plugin.
@@ -138,11 +128,11 @@ public:
      * @param parent the parent containment. @since 4.6 null is allowed.
      * @param name the plugin name, as returned by KPluginInfo::pluginName()
      * @param args to send the containmentactions extra arguments
-     * @return a ContaimentActions object
+     * @return a ContainmentActions object
      **/
-    ContainmentActions *loadContainmentActions(Containment *parent, const QString &containmentActionsName,
-            const QVariantList &args = QVariantList());
+    ContainmentActions *loadContainmentActions(Containment *parent, const QString &containmentActionsName, const QVariantList &args = QVariantList());
 
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 30)
     /**
      * Load a Package plugin.
      *
@@ -150,10 +140,34 @@ public:
      * @param specialization used to find script extensions for the given format, e.g. "QML" for "Plasma/Applet"
      *
      * @return a Package object matching name, or an invalid package on failure
-     * @deprecated since 5.29 use KPackage::PackageLoader::loadPackage
+     * @deprecated Since 5.30, use KPackage::PackageLoader::loadPackage(const QString& packageFormat, const QString& packagePath) instead.
      **/
-#ifndef PLASMA_NO_DEPRECATED
-    PLASMA_DEPRECATED Package loadPackage(const QString &packageFormat, const QString &specialization = QString());
+    PLASMA_DEPRECATED_VERSION(5, 30, "Use KPackage::PackageLoader::loadPackage(const QString&, const QString&")
+    Package loadPackage(const QString &packageFormat, const QString &specialization = QString());
+#endif
+
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 28)
+    /**
+     * Returns a list of all known applets.
+     * This may skip applets based on security settings and ExcludeCategories in the application's config.
+     *
+     * @param category Only applets matching this category will be returned.
+     *                 Useful in conjunction with knownCategories.
+     *                 If "Misc" is passed in, then applets without a
+     *                 Categories= entry are also returned.
+     *                 If an empty string is passed in, all applets are
+     *                 returned.
+     * @param parentApp the application to filter applets on. Uses the
+     *                  X-KDE-ParentApp entry (if any) in the plugin info.
+     *                  The default value of QString() will result in a
+     *                  list of all applets in specified category.
+     * @return list of applets
+     *
+     * @deprecated Since 5.28. Doesn't support metadata.json packages.
+     * Use listAppletMetaData(const QString &category, const QString &parentApp) instead.
+     **/
+    PLASMA_DEPRECATED_VERSION(5, 28, "Use PluginLoader::listAppletMetaData(const QString &, const QString &)")
+    KPluginInfo::List listAppletInfo(const QString &category, const QString &parentApp = QString());
 #endif
 
     /**
@@ -169,64 +183,50 @@ public:
      * @param parentApp the application to filter applets on. Uses the
      *                  X-KDE-ParentApp entry (if any) in the plugin info.
      *                  The default value of QString() will result in a
-     *                  list containing only applets not specifically
-     *                  registered to an application.
-     * @return list of applets
-     *
-     * @deprecated use listAppletMetaData. Doesn't support metadata.json packages.
-     **/
-    PLASMA_DEPRECATED KPluginInfo::List listAppletInfo(const QString &category, const QString &parentApp = QString());
-
-    /**
-     * Returns a list of all known applets.
-     * This may skip applets based on security settings and ExcludeCategories in the application's config.
-     *
-     * @param category Only applets matchin this category will be returned.
-     *                 Useful in conjunction with knownCategories.
-     *                 If "Misc" is passed in, then applets without a
-     *                 Categories= entry are also returned.
-     *                 If an empty string is passed in, all applets are
-     *                 returned.
-     * @param parentApp the application to filter applets on. Uses the
-     *                  X-KDE-ParentApp entry (if any) in the plugin info.
-     *                  The default value of QString() will result in a
-     *                  list containing only applets not specifically
-     *                  registered to an application.
+     *                  list of all applets in specified categories.
      * @return list of applets
      *
      * @since 5.28
      **/
     QList<KPluginMetaData> listAppletMetaData(const QString &category, const QString &parentApp = QString());
 
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 36)
     /**
      * Returns a list of all known applets associated with a certain mimetype.
      *
      * @return list of applets
      *
-     * @deprecated use listAppletMetaDataForMimeType instead
+     * @deprecated Since 5.36, use listAppletMetaDataForMimeType(const QString &mimetype) instead.
      **/
-    PLASMA_DEPRECATED KPluginInfo::List listAppletInfoForMimeType(const QString &mimetype);
+    PLASMA_DEPRECATED_VERSION(5, 36, "Use PluginLoader::listAppletMetaDataForMimeType(const QString &)")
+    KPluginInfo::List listAppletInfoForMimeType(const QString &mimetype);
+#endif
 
     /**
      * Returns a list of all known applets associated with a certain mimetype.
      *
      * @return list of applets
+     * @since 5.36
      **/
     QList<KPluginMetaData> listAppletMetaDataForMimeType(const QString &mimetype);
 
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 36)
     /**
      * Returns a list of all known applets associated with a certain URL.
      *
      * @return list of applets
      *
-     * @deprecated use listAppletMetaDataForUrl instead
+     * @deprecated Since 5.36, use listAppletMetaDataForUrl(const QUrl &url) instead.
      **/
-    PLASMA_DEPRECATED KPluginInfo::List listAppletInfoForUrl(const QUrl &url);
+    PLASMA_DEPRECATED_VERSION(5, 36, "Use PluginLoader::listAppletMetaDataForUrl(const QUrl &)")
+    KPluginInfo::List listAppletInfoForUrl(const QUrl &url);
+#endif
 
     /**
      * Returns a list of all known applets associated with a certain URL.
      *
      * @return list of applets
+     * @since 5.36
      **/
     QList<KPluginMetaData> listAppletMetaDataForUrl(const QUrl &url);
 
@@ -236,13 +236,11 @@ public:
      * @param parentApp the application to filter applets on. Uses the
      *                  X-KDE-ParentApp entry (if any) in the plugin info.
      *                  The default value of QString() will result in a
-     *                  list containing only applets not specifically
-     *                  registered to an application.
+     *                  list of all Applets.
      * @return list of categories
      * @param visibleOnly true if it should only return applets that are marked as visible
      */
-    QStringList listAppletCategories(const QString &parentApp = QString(),
-                                     bool visibleOnly = true);
+    QStringList listAppletCategories(const QString &parentApp = QString(), bool visibleOnly = true);
 
     /**
      * Sets the list of custom categories that are used in addition to the default
@@ -265,6 +263,7 @@ public:
      */
     QString appletCategory(const QString &appletName);
 
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 83)
     /**
      * Returns a list of all known containments.
      *
@@ -277,20 +276,40 @@ public:
      * @param parentApp the application to filter containments on. Uses the
      *                  X-KDE-ParentApp entry (if any) in the plugin info.
      *                  The default value of QString() will result in a
-     *                  list containing only containments not specifically
-     *                  registered to an application.
+     *                  list of all containments.
+     * @deprecated since 5.83, use PluginLoader::listContainmentsMetaData
      * @return list of containments
      **/
-    static KPluginInfo::List listContainments(const QString &category = QString(),
-            const QString &parentApp = QString());
+    PLASMA_DEPRECATED_VERSION(5, 83, "Use PluginLoader::listContainmentsMetaData")
+    static KPluginInfo::List listContainments(const QString &category = QString(), const QString &parentApp = QString());
+#endif
 
+    /**
+     * Returns a list of all known containments.
+     *
+     * @param filter An optional predicate that can be used for filtering.
+     *
+     * @return list of containments
+     */
+    static QList<KPluginMetaData> listContainmentsMetaData(std::function<bool(const KPluginMetaData &)> filter = {});
+
+    /**
+     * Returns a list of containments of the specified type.
+     *
+     * @param type The target containment type
+     *
+     * @return list of containments
+     */
+    static QList<KPluginMetaData> listContainmentsMetaDataOfType(const QString &type);
+
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 83)
     /**
      * Returns a list of all known containments that match the parameters.
      *
      * @param type Only containments with this string in X-Plasma-ContainmentType
      *             in their .desktop files will be returned. Common values are panel and
      *             desktop
-     * @param category Only containments matchin this category will be returned.
+     * @param category Only containments matching this category will be returned.
      *                 Useful in conjunction with knownCategories.
      *                 If "Miscellaneous" is passed in, then containments without a
      *                 Categories= entry are also returned.
@@ -299,25 +318,49 @@ public:
      * @param parentApp the application to filter containments on. Uses the
      *                  X-KDE-ParentApp entry (if any) in the plugin info.
      *                  The default value of QString() will result in a
-     *                  list containing only containments not specifically
-     *                  registered to an application.
+     *                  list of all containments, matching categories/type.
+     * @deprecated since 5.83, use PluginLoader::listContainmentsMetaDataOfType
      * @return list of containments
      **/
-    static KPluginInfo::List listContainmentsOfType(const QString &type,
-            const QString &category = QString(),
-            const QString &parentApp = QString());
+    PLASMA_DEPRECATED_VERSION(5, 83, "Use PluginLoader::listContainmentsMetaDataOfType")
+    static KPluginInfo::List listContainmentsOfType(const QString &type, const QString &category = QString(), const QString &parentApp = QString());
+#endif
 
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 83)
     /**
      * @return a list of all known types of containments on this system
      */
+    PLASMA_DEPRECATED_VERSION(5,
+                              83,
+                              "Use PluginLoader::listContainmentsMetaDataOfType and aggregate the values of the X-Plasma-ContainmentType property instead")
     static QStringList listContainmentTypes();
+#endif
 
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 83)
     /**
      * Returns a list of all known containments associated with a certain MimeType
      *
      * @return list of containments
+     * @deprecated since 5.83, use listAppletMetaData() with custom filtering instead.
      **/
+    PLASMA_DEPRECATED_VERSION(5, 83, "Use listAppletMetaData() with custom filtering")
     static KPluginInfo::List listContainmentsForMimeType(const QString &mimeType);
+#endif
+
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 77)
+    /**
+     * Returns a list of all known dataengines.
+     *
+     * @param parentApp the application to filter dataengines on. Uses the
+     *                  X-KDE-ParentApp entry (if any) in the plugin info.
+     *                  The default value of QString() will result in a
+     *                  list of all dataengines
+     * @return list of dataengines
+     * @deprecated since 5.77, use listDataEngineMetaData()
+     **/
+    PLASMA_DEPRECATED_VERSION(5, 77, "Use listDataEngineMetaData()")
+    KPluginInfo::List listDataEngineInfo(const QString &parentApp = QString());
+#endif
 
     /**
      * Returns a list of all known dataengines.
@@ -325,23 +368,38 @@ public:
      * @param parentApp the application to filter dataengines on. Uses the
      *                  X-KDE-ParentApp entry (if any) in the plugin info.
      *                  The default value of QString() will result in a
-     *                  list containing only dataengines not specifically
-     *                  registered to an application.
+     *                  list of all dataengines
      * @return list of dataengines
+     * @since 5.77
      **/
-    KPluginInfo::List listDataEngineInfo(const QString &parentApp = QString());
+    QVector<KPluginMetaData> listDataEngineMetaData(const QString &parentApp = QString());
 
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 77)
     /**
      * Returns a list of all known ContainmentActions.
      *
      * @param parentApp the application to filter ContainmentActions on. Uses the
      *                  X-KDE-ParentApp entry (if any) in the plugin info.
      *                  The default value of QString() will result in a
-     *                  list containing only ContainmentActions not specifically
-     *                  registered to an application.
+     *                  list of all ContainmentActions.
      * @return list of ContainmentActions
+     * @deprecated since 5.77, use listContainmentActionsMetaData()
      **/
+    PLASMA_DEPRECATED_VERSION(5, 77, "Use listContainmentActionsMetaData()")
     KPluginInfo::List listContainmentActionsInfo(const QString &parentApp);
+#endif
+
+    /**
+     * Returns a list of all known ContainmentActions.
+     *
+     * @param parentApp the application to filter ContainmentActions on. Uses the
+     *                  X-KDE-ParentApp entry (if any) in the plugin metadata.
+     *                  The default value of QString() will result in a
+     *                  list of all ContainmentActions.
+     * @return list of ContainmentActions
+     * @since 5.77
+     **/
+    QVector<KPluginMetaData> listContainmentActionsMetaData(const QString &parentApp);
 
     /**
      * Set the plugin loader which will be queried for all loads.
@@ -370,8 +428,7 @@ protected:
      * @param args to send the applet extra arguments
      * @return a pointer to the loaded applet, or 0 on load failure
      **/
-    virtual Applet *internalLoadApplet(const QString &name, uint appletId = 0,
-                                       const QVariantList &args = QVariantList());
+    virtual Applet *internalLoadApplet(const QString &name, uint appletId = 0, const QVariantList &args = QVariantList());
 
     /**
      * A re-implementable method that allows subclasses to override
@@ -398,7 +455,7 @@ protected:
      *
      * @return a Service object, unlike Plasma::Service::loadService, this can return null.
      **/
-    virtual Service *internalLoadService(const QString &name, const QVariantList &args, QObject *parent = 0);
+    virtual Service *internalLoadService(const QString &name, const QVariantList &args, QObject *parent = nullptr);
 
     /**
      * A re-implementable method that allows subclasses to override
@@ -414,10 +471,11 @@ protected:
      * @param parent the parent containment. @since 4.6 null is allowed.
      * @param name the plugin name, as returned by KPluginInfo::pluginName()
      * @param args to send the containmentactions extra arguments
-     * @return a ContaimentActions object
+     * @return a ContainmentActions object
      **/
     virtual ContainmentActions *internalLoadContainmentActions(Containment *parent, const QString &containmentActionsName, const QVariantList &args);
 
+#if PLASMA_BUILD_DEPRECATED_SINCE(5, 83)
     /**
      * A re-implementable method that allows subclasses to override
      * the default behaviour of loadPackage. If the service requested is not recognized,
@@ -430,12 +488,11 @@ protected:
      * @param parent the parent object, if any, for the service
      *
      * @return a Service object, unlike Plasma::Service::loadService, this can return null.
-     * @deprecated since 5.29
+     * @deprecated since 5.30, use KPackage API
      **/
-#ifndef PLASMA_NO_DEPRECATED
-    virtual PLASMA_DEPRECATED Package internalLoadPackage(const QString &name, const QString &specialization);
+    PLASMA_DEPRECATED_VERSION(5, 30, "Use KPackage API")
+    virtual Package internalLoadPackage(const QString &name, const QString &specialization);
 #endif
-
     /**
      * A re-implementable method that allows subclasses to provide additional applets
      * for listAppletInfo. If the application has no applets to give to the application,
