@@ -1,34 +1,20 @@
 /*
- *   Copyright 2007 by Aaron Seigo <aseigo@kde.org>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2007 Aaron Seigo <aseigo@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef PLASMA_DATAENGINESCRIPT_H
 #define PLASMA_DATAENGINESCRIPT_H
 
-#include <kplugininfo.h>
+#include <KPluginInfo>
 
-#include <plasma/plasma_export.h>
 #include <plasma/dataengine.h>
+#include <plasma/plasma_export.h>
 #include <plasma/scripting/scriptengine.h>
 
 namespace Plasma
 {
-
 class DataEngineScriptPrivate;
 class Service;
 
@@ -49,8 +35,8 @@ public:
      * such set up that requires the DataEngine itself should be done
      * in the init() method.
      */
-    explicit DataEngineScript(QObject *parent = 0);
-    ~DataEngineScript();
+    explicit DataEngineScript(QObject *parent = nullptr);
+    ~DataEngineScript() override;
 
     /**
      * Sets the Plasma::DataEngine associated with this DataEngineScript
@@ -98,25 +84,39 @@ public:
     virtual Service *serviceForSource(const QString &source);
 
 protected:
+#if PLASMA_BUILD_DEPRECATED_SINCE(5, 83)
     /**
      * @return absolute path to the main script file for this plasmoid
      */
-    QString mainScript() const Q_DECL_OVERRIDE;
+    QString mainScript() const override;
 
     /**
      * @return the Package associated with this plasmoid which can
      *         be used to request resources, such as images and
      *         interface files.
      */
-    Package package() const Q_DECL_OVERRIDE;
+    PLASMA_DEPRECATED_VERSION(5, 83, "Use kpackage API instead")
+    Package package() const override;
+#endif
+
+#if PLASMA_ENABLE_DEPRECATED_SINCE(5, 67)
+    /**
+     * @return the KPluginInfo associated with this dataengine
+     *
+     * @deprecated since 5.67 use metadata()
+     */
+    PLASMA_DEPRECATED_VERSION(5, 67, "Use KPluginMetaData metadata()")
+    KPluginInfo description() const;
+#endif
 
     /**
-     * @return the KPluginInfo associated with this plasmoid
+     * @return the KPluginMetaData associated with this dataengine
+     *
+     * @since 5.67
      */
-    KPluginInfo description() const;
+    KPluginMetaData metadata() const;
 
-    void setData(const QString &source, const QString &key,
-                 const QVariant &value);
+    void setData(const QString &source, const QString &key, const QVariant &value);
     void setData(const QString &source, const QVariant &value);
 
     /**
@@ -130,7 +130,7 @@ protected:
     void removeAllData(const QString &source);
     void removeData(const QString &source, const QString &key);
     void setMinimumPollingInterval(int minimumMs);
-    int  minimumPollingInterval() const;
+    int minimumPollingInterval() const;
     void setPollingInterval(uint frequency);
     void removeAllSources();
     void addSource(DataContainer *source);
@@ -143,9 +143,11 @@ private:
     DataEngineScriptPrivate *const d;
 };
 
-#define K_EXPORT_PLASMA_DATAENGINESCRIPTENGINE(libname, classname) \
-    K_PLUGIN_FACTORY(factory, registerPlugin<classname>();)
+#define K_EXPORT_PLASMA_DATAENGINESCRIPTENGINE(libname, classname) K_PLUGIN_FACTORY(factory, registerPlugin<classname>();)
 
-} //Plasma namespace
+#define K_EXPORT_PLASMA_DATAENGINESCRIPTENGINE_WITH_JSON(libname, classname, jsonFile)                                                                         \
+    K_PLUGIN_FACTORY_WITH_JSON(factory, jsonFile, registerPlugin<classname>();)                                                                                \
+    K_EXPORT_PLUGIN_VERSION(PLASMA_VERSION)
+} // Plasma namespace
 
 #endif
